@@ -18,7 +18,7 @@ Where:
 
 - data plugins - load data from various format and transform it in a list of dictionaries
 - processor plugins - optional step, but can be used to pre-process data before rendering
-- template loaders - retrieve template context from various sources
+- template loaders - retrieve template content from various sources (files, directories etc.)
 - renderes - iterate over list of dictionaries data and render each item with template
 - returners - return rendering results to various destinations, e.g. save to file system
 
@@ -30,12 +30,18 @@ How it works
 
 On the base level TTR takes list of dictionaries, renders each dictionary with template
 defined in ``template_name_key`` and saves rendered data in results dictionary keyed by 
-``result_name_key``. 
-
-Each dictionary item must contain ``template_name_key`` and ``result_name_key`` keys.
+``result_name_key``. Because of that each dictionary item must contain ``template_name_key`` 
+and ``result_name_key`` keys.
 
 Various plugins can be used to load data in a list of dictionaries with other plugins 
 helping to process it, render and save results.
+
+TTR API reference
+=================
+
+.. autoclass:: ttr.ttr
+  :noindex:
+  :members:
 """
 __version__ = "0.1.0"
 
@@ -45,6 +51,7 @@ from .plugins.data import data_plugins
 from .plugins.renderers import renderers_plugins
 from .plugins.returners import returners_plugins
 from .plugins.processors import processors_plugins
+from .plugins.templates import templates_loaders_plugins
 
 log = logging.getLogger(__name__)
 
@@ -59,7 +66,7 @@ class ttr:
     :param data_plugin_kwargs: (dict) arguments to pass on to data plugin
     :param renderer: (str) name of renderer plugin to use, default ``jinja2``
     :param renderer_kwargs: (dict) arguments to pass on to renderer plugin
-    :param templates_dir: (str) OS pat to directory with templates, default ``./Templates/``
+    :param templates: (str) OS pat to directory or file with templates, default ``./Templates/``
     :param template_name_key: (str) name of the key in data items that reference template
         to use to render that particular datum, default ``template``
     :param returner: (str) name of returner plugin to use, default ``self``
@@ -70,6 +77,7 @@ class ttr:
         through, default is empty list - no processors applied
     :param templates_dict: (dict) dictionary of {template_name: template_content}
     """
+
     def __init__(
         self,
         data=None,
@@ -77,18 +85,18 @@ class ttr:
         data_plugin_kwargs={},
         renderer="jinja2",
         renderer_kwargs={},
-        templates_dir="./Templates/",
+        templates="./Templates/",
         template_name_key="template",
         returner="self",
         returner_kwargs={},
         result_name_key="device",
         processors=[],
         processors_kwargs={},
-        templates_dict={}
+        templates_dict={},
     ):
         self.data_plugin = data_plugin
         self.data_plugin_kwargs = data_plugin_kwargs
-        self.templates_dir = templates_dir
+        self.templates = templates
         self.templates_dict = templates_dict or {}
         self.template_name_key = template_name_key
         self.renderer = renderer
@@ -105,15 +113,12 @@ class ttr:
         if data:
             self.load_data(data)
 
-
     def __enter__(self):
         return self
 
-
     def __exit__(self, type, value, traceback):
         del self.data_loaded, self.templates_dict, self.results
 
-
     def load_data(self, data, data_plugin=None):
         """
         Method to load data to render.
@@ -130,9 +135,12 @@ class ttr:
             # get data loader name based on data file extension
             plugin_name = data.split(".")[-1].strip()
         else:
-            log.error("load_data: failed to identify data plugin to load data '{}'".format(data[:100]))
+            log.error(
+                "load_data: failed to identify data plugin to load data '{}'".format(
+                    data[:100]
+                )
+            )
             return
-
         # load data using plugin
         log.debug("Loading data using '{}' plugin".format(plugin_name))
         self.data_plugin_kwargs.setdefault("template_name_key", self.template_name_key)
@@ -141,7 +149,9 @@ class ttr:
 
         # process loaded data
         for processor_plugin in self.processors:
-            log.debug("Running loaded data through processor: '{}'".format(processor_plugin))
+            log.debug(
+                "Running loaded data through processor: '{}'".format(processor_plugin)
+            )
             self.data_loaded = processors_plugins[processor_plugin](
                 data=self.data_loaded,
                 data_plugin=self.data_plugin,
@@ -149,10 +159,48 @@ class ttr:
                 result_name_key=self.result_name_key,
                 **self.processors_kwargs
             )
-            
         if log.isEnabledFor(logging.DEBUG):
             log.debug("Data loaded:\n{}".format(self.data_loaded))
 
+    def load_templates(
+        self,
+        template_name="",
+        template_content="",
+        templates="",
+        templates_plugin="",
+        **kwargs
+    ):
+        """
+        Function to load templates content in templates dictionary.
+
+        :param template_name: (str) name of template to load
+        :param template_content: (str) template content to save in templates dictionary under ``template_name``
+        :param templates: (str) OS pat to directory or file with templates, default ``./Templates/``
+        :param templates_plugin: (str) templates loader plugin to use - ``base, xlsx, dir, file, ttr``
+        :param kwargs: any additional ``**kwargs`` to pass on to ``templates_plugin``
+
+        Decision logic:
+
+        1. If ``template_content`` provided add it to templates dictionary under ``template_name`` key
+        2. If valid ``templates_plugin`` name given use it to load template
+        3. Use ``base`` templates loader plugin to load template content
+        """
+        if template_name and template_content:
+            self.templates_dict[template_name] = template_content
+        elif templates_plugin in templates_loaders_plugins:
+            templates_loaders_plugins[templates_plugin](
+                templates_dict=self.templates_dict,
+                templates=templates,
+                template_name=template_name,
+                **kwargs
+            )
+        else:
+            templates_loaders_plugins["base"](
+                templates_dict=self.templates_dict,
+                templates=templates,
+                template_name=template_name,
+            )
+
     def run(self):
         """
         Method to render templates with data and produce dictionary results
@@ -165,17 +213,14 @@ class ttr:
         self.results = renderers_plugins[self.renderer](
             self.data_loaded,
             self.template_name_key,
-            self.templates_dir,
+            self.templates,
             self.templates_dict,
             self.result_name_key,
             **self.renderer_kwargs
         )
         # return results
         log.debug("Returning results using '{}' returner".format(self.returner))
-        returners_plugins[self.returner](
-            self.results,
-            **self.returner_kwargs
-        )
+        returners_plugins[self.returner](self.results, **self.returner_kwargs)
         log.debug("TTR rendering run completed")
         if self.returner == "self":
             return self.results
